@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.2
+# @version 2.6.0
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -43,14 +43,15 @@ class Framework:
     plasmalib    = ""                        # plasma library
     plasmaurl    = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/plasma.tar.gz"
     urlbase      = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs"
-    versions     = ("2.5.2", "2.5.1", "2.5.0b1",
+    versions     = ("2.6.0",
+                    "2.5.3", "2.5.2", "2.5.1", "2.5.0b1",
                     "2.4.6", "2.4.5", "2.4.2", "2.4.1", "2.4.0",
                     "2.3.1", "2.3.0",
                     "2.2.0", "2.1.0",
                     "2.0.0",
                     "1.0.1", "1.0.0")
     oldversions  = ("2.1.0", "2.0.0", "1.0.1", "1.0.0") # Releases from version which need the internal cblas and lapack
-    lapversion   = "lapack-3.4.2"
+    lapversion   = "lapack-3.5.0"
     ranlib       = ""                        # the ranlib command
     clean        = 0
     nbcores      = 2
@@ -228,7 +229,7 @@ You can specify it using the --fc flag."""
    --downall           : Download and install all missing external libraries.
                          If you don't have access to wget or no network
                          connection, you can provide the following packages
-                         in the directory builddir/download:
+                         in the directory build/download:
         http://netlib.org/blas/blas.tgz
         http://www.netlib.org/blas/blast-forum/cblas.tgz
         http://www.netlib.org/lapack/%s.tgz
